function ret = correct_sfb(sfb)
%
%   ret = correct_sfb(sfb)
%
%      tests correctness of given sfb format and returns true/false
%
% (c) Jana Kostliva (kostliva@cmp.felk.cvut.cz)
%     CMP, FEE CTU in Prague, 23-Apr-2007

ret = 0;

scenes = {'cones','slits','stripes','teddy','tsukuba', ...
	  'venus','expected'};

if (~isfield(sfb, 'version'))
  disp('Error: Given SFB does not have required format:')
  disp('    missing field ''version''')
  return
end

for sc = 1:size(scenes,2)
  scene = scenes{sc};

  if (~isfield(sfb, sprintf('%s',scene)))
    disp('Error: Given SFB does not have required format:')
    disp(sprintf('    missing results of scene ''%s''', scene))
    return
  else
    curr_sfb = getfield(sfb, sprintf('%s', scene));
    if (~isfield(curr_sfb, 'SR'))
      disp('Error: Given SFB does not have required format:')
      disp(sprintf('    missing field ''%s.SR''', scene))
      return
    end
    if (~isfield(curr_sfb, 'ER'))
      disp('Error: Given SFB does not have required format:')
      disp(sprintf('    missing field ''%s.ER''', scene))
      return
    end
    if (~isfield(curr_sfb, 'algs'))
      disp('Error: Given SFB does not have required format:')
      disp(sprintf('    missing field ''%s.algs''', scene))
      return
    end
    if (~isfield(curr_sfb, 'param_names'))
      disp('Error: Given SFB does not have required format:')
      disp(sprintf('    missing field ''%s.param_names''', scene))
      return
    end
    if (~isfield(curr_sfb, 'params'))
      disp('Error: Given SFB does not have required format:')
      disp(sprintf('    missing field ''%s.params''', scene))
      return
    end
    if (~isfield(curr_sfb, 'param_num'))
      disp('Error: Given SFB does not have required format:')
      disp(sprintf('    missing field ''%s.param_num''', scene))
      return
    end
    if (~isfield(curr_sfb, 'E'))
      disp('Error: Given SFB does not have required format:')
      disp(sprintf('    missing field ''%s.E''', scene))
      return
    end
    if (size(curr_sfb.SR,2) ~= size(curr_sfb.ER,2))
      disp('Error: Given SFB does not have required format:')
      disp(sprintf('    all fields in ''SFB.%s'' must have the same length',...
		   scene))
      return
    end
    if (size(curr_sfb.SR,2) ~= size(curr_sfb.algs,2))
      disp('Error: Given SFB does not have required format:')
      disp(sprintf('    all fields in ''SFB.%s'' must have the same length',...
		   scene))
      return
    end
    if (size(curr_sfb.SR,2) ~= size(curr_sfb.param_names,2))
      disp('Error: Given SFB does not have required format:')
      disp(sprintf('    all fields in ''SFB.%s'' must have the same length',...
		   scene))
      return
    end
    if (size(curr_sfb.SR,2) ~= size(curr_sfb.params,2))
      disp('Error: Given SFB does not have required format:')
      disp(sprintf('    all fields in ''SFB.%s'' must have the same length',...
		   scene))
      return
    end
    if (size(curr_sfb.SR,2) ~= size(curr_sfb.param_num,2))
      disp('Error: Given SFB does not have required format:')
      disp(sprintf('    all fields in ''SFB.%s'' must have the same length',...
		   scene))
      return
    end
    if ((min(curr_sfb.SR) < 0) | (max(curr_sfb.SR > 1)))
      disp('Error: Given SFB does not have required format:')
      disp(sprintf('    field ''SFB.%s.SR'' are rates (interval (0,1))',...
		   scene))
      return
    end
    if ((min(curr_sfb.ER) < 0) | (max(curr_sfb.ER > 1)))
      disp('Error: Given SFB does not have required format:')
      disp(sprintf('    field ''SFB.%s.ER'' are rates (interval (0,1))',...
		   scene))
      return
    end
    ret = 1;
  end
end

