function ret = correct_sroc(sroc)
%
%   ret = correct_sroc(sroc)
%
%     tests correctness of given sroc profile format and 
%     returns true/false
%
% (c) Jana Kostliva (kostliva@cmp.felk.cvut.cz)
%     CMP, FEE CTU in Prague, 23-Apr-2007

ret = 0;


if (~isfield(sroc, 'scenes'))
  disp('Error: Given SROC profile does not have required format:')
  disp('    missing field ''scenes''')
  return
end

if (~isfield(sroc, 'param_name'))
  disp('Error: Given SROC profile does not have required format:')
  disp('    missing field ''param_name''')
  return
end

if (~isfield(sroc, 'params'))
  disp('Error: Given SROC profile does not have required format:')
  disp('    missing field ''params''')
  return
end

if (size(sroc.params,1) ~= size(sroc.param_name,2))
  disp('Error: Given SROC profile does not have required format:')
  disp('    number of rows in ''SROC.params'' must equal to number of parameters (given in SROC.param_name)')
  return
end


for sc = 1:size(sroc.scenes,2)
  scene = sroc.scenes{sc};

  if (~isfield(sroc, sprintf('%s',scene)))
    disp('Error: Given SROC profile does not have required format:')
    disp(sprintf('    missing results of scene ''%s''', scene))
    return
  else
    rates = getfield(sroc, sprintf('%s', scene));
    if (~isfield(rates, 'SR'))
      disp('Error: Given SROC profiledoes not have required format:')
      disp(sprintf('    missing field ''%s.SR''', scene))
      return
    end
    if (~isfield(rates, 'ER'))
      disp('Error: Given SROC profile does not have required format:')
      disp(sprintf('    missing field ''%s.ER''', scene))
      return
    end
    if (~isfield(rates, 'ROC'))
      disp('Error: Given SROC profile does not have required format:')
      disp(sprintf('    missing field ''%s.ROC''', scene))
      return
    end
    if (~isfield(rates, 'E'))
      disp('Error: Given SROC profile does not have required format:')
      disp(sprintf('    missing field ''%s.E''', scene))
      return
    end
    if (size(rates.SR,2) ~= size(rates.ER,2))
      disp('Error: Given SROC profile does not have required format:')
      disp(sprintf('    all fields in ''SROC.%s'' must have the same length',...
		   scene))
      return
    end
    if (size(rates.SR,2) ~= size(sroc.params,2))
      disp('Error: Given SROC profile does not have required format:')
      disp(sprintf('    ''SROC.%s.SR'' length must equal to ''SROC.params''',...
		   scene))
      return
    end
    if (size(rates.ER,2) ~= size(sroc.params,2))
      disp('Error: Given SROC profile does not have required format:')
      disp(sprintf('    ''SROC.%s.ER'' length must equal to ''SROC.params''',...
		   scene))
      return
    end
    if ((min(rates.ROC) < 1) | (max(rates.ROC) > size(sroc.params,2)))
      disp('Error: Given SROC profile does not have required format:')
      disp(sprintf('    field ''SROC.%s.ROC'' should be indexes', scene))
      return
    end
    if ((min(rates.SR) < 0) | (max(rates.SR > 1)))
      disp('Error: Given SROC profile does not have required format:')
      disp(sprintf('    field ''SROC.%s.SR'' are rates (interval (0,1))',...
		   scene))
      return
    end
    if ((min(rates.ER) < 0) | (max(rates.ER > 1)))
      disp('Error: Given SROC profile does not have required format:')
      disp(sprintf('    field ''SROC.%s.ER'' are rates (interval (0,1))',...
		   scene))
      return
    end
  end
end

if (~isfield(sroc, 'expected'))
  disp('Error: Given SROC profiledoes not have required format:')
  disp('    missing field ''expected''')
  return
end
if (~isfield(sroc.expected, 'SR'))
  disp('Error: Given SROC profiledoes not have required format:')
  disp('    missing field ''expected.SR''')
  return
end
if (~isfield(sroc.expected, 'ER'))
  disp('Error: Given SROC profile does not have required format:')
  disp('    missing field ''expected.ER''')
  return
end
if (~isfield(sroc.expected, 'ROC'))
  disp('Error: Given SROC profile does not have required format:')
  disp('    missing field ''expected.ROC''')
  return
end
if (~isfield(sroc.expected, 'E'))
  disp('Error: Given SROC profile does not have required format:')
  disp('    missing field ''expected.E''')
  return
end
if (size(sroc.expected.SR,2) ~= size(sroc.expected.ER,2))
  disp('Error: Given SROC profile does not have required format:')
  disp('    SR,ER fields in ''SROC.expected'' must have the same length')
  return
end
if (size(sroc.expected.SR,2) ~= size(sroc.params,2))
  disp('Error: Given SROC profile does not have required format:')
  disp('    ''SROC.expected.SR'' length must equal to ''SROC.params''')
  return
end
if (size(sroc.expected.ER,2) ~= size(sroc.params,2))
  disp('Error: Given SROC profile does not have required format:')
  disp('    ''SROC.expecteds.ER'' length must equal to ''SROC.params''')
  return
end
if ((min(sroc.expected.ROC) < 1) | ...
    (max(sroc.expected.ROC) > size(sroc.params,2)))
  disp('Error: Given SROC profile does not have required format:')
  disp('    field ''SROC.expected.ROC'' should be indexes')
  return
end
if ((min(sroc.expected.SR) < 0) | (max(sroc.expected.SR > 1)))
  disp('Error: Given SROC profile does not have required format:')
  disp('    field ''SROC.expected.SR'' are rates (interval (0,1))')
  return
end
if ((min(sroc.expected.ER) < 0) | (max(sroc.expected.ER > 1)))
  disp('Error: Given SROC profile does not have required format:')
  disp('    field ''SROC.expected.ER'' are rates (interval (0,1))')
  return
end

ret = 1;

return
