function sfb = sroc_compute_sfb(algs, ResPth, curr_sfb)
%
%    sfb = sroc_compute_sfb(algs, ResPth[, curr_sfb])
%
%             computes new Stereo feasibility boundary from 
%             given algorithms and current sfb
%
%      Input:
%      algs ... abbreviations of algorithms sfb is to be computed from
%    ResPth ... path where results of algorithms algs are stored
%  curr_sfb ... current SFB; optional, if not given SFB just from 
%               algs is com[puted
%
%     Output:
%       sfb ... new SFB
%
% (c) Jana Kostliva (kostliva@cmp.felk.cvut.cz)
%     CMP, FEE CTU in Prague, 23-Apr-2007
%

if (nargin < 3) 
  is_sfb = 0;
else
  is_sfb = 1;
end

sfb = [];
sfb.version = 'unofficial';

% load results of all algorithms
Alg = [];
for al = 1:size(algs,2)
  alg = algs{al};
  load(sprintf('%s/%s/sroc_%s.mat', ResPth, alg, alg))
  % tests if sroc profile has correct format
  if (~correct_sroc(sroc))
    return
  end
  Alg{al} = sroc;
end

scenes = {'cones','slits','stripes','teddy','tsukuba', ...
	  'venus','expected'};

for sc = 1:size(scenes,2)

  scene = scenes{sc};

  sfb_SR = [];
  sfb_ER = [];
  sfb_algs = {};
  sfb_param_names = {};
  sfb_params = {};
  sfb_param_num = [];

  for al = 1:size(algs,2)
     if (~isfield(Alg{al}, sprintf('%s', scene)))
 	continue  
     end	  
     
     rates = getfield(Alg{al},sprintf('%s',scene));
     sfb_SR = [sfb_SR, rates.SR(rates.ROC)];
     sfb_ER = [sfb_ER, rates.ER(rates.ROC)];
     sfb_algs = [sfb_algs{:}, repmat({Alg{al}.alg_abbrv},...
       1, size(rates.ROC,2))];
     sfb_param_names = [sfb_param_names,...
			repmat({Alg{al}.param_name},...
			       1, size(rates.ROC,2))];

     for i=1:size(rates.ROC,2)
       sfb_params = [sfb_params{:}, {Alg{al}.params(:,rates.ROC(i))}];
     end
     sfb_param_num = [sfb_param_num, rates.ROC];

  end     

  if (is_sfb)			    
    c_sfb = getfield(curr_sfb, sprintf('%s',scene));
    sfb_SR = [sfb_SR, c_sfb.SR];
    sfb_ER = [sfb_ER, c_sfb.ER];
    sfb_algs = [sfb_algs, c_sfb.algs];
    sfb_param_names = [sfb_param_names, c_sfb.param_names];
    sfb_params = [sfb_params, c_sfb.params];
    sfb_param_num = [sfb_param_num, c_sfb.param_num];
  end

  sr = sfb_SR;
  er = sfb_ER;
  Ind = [];
  while (~isempty(sr))
    ind = find(sfb_ER == min(er));  
    indx = find(er == min(er));
    ind1 = find(sfb_SR(ind) == min(sr(indx)));
    Ind = [ind(ind1) Ind];
    
    ind2 = find((sr >= sfb_SR(ind(ind1(1)))) & (er >= sfb_ER(ind(ind1(1)))));
    sr(ind2) = [];
    er(ind2) = [];
  end			    

  Eff = sroc_efficiency([sfb_SR(Ind);sfb_ER(Ind)]);

  sfb = setfield(sfb, sprintf('%s', scene),...
		 struct('SR', sfb_SR(Ind), 'ER', sfb_ER(Ind),...
			'algs', {sfb_algs(Ind)}, 'param_names',...
		        {sfb_param_names(Ind)}, 'params',...
		        {sfb_params(Ind)}, 'param_num',...
			sfb_param_num(Ind), 'E', Eff));

end

