function sroc = sroc_eval_example(sroc)
%
% sroc = sroc_eval_example(sroc)
% 
%     script for the algorithm evaluation, saves results
%     if sroc.export_results = true, exports E to 
%         'Efficiency.tex' file
%
% (c) Jana Kostliva (kostliva@cmp.felk.cvut.cz)
%     CMP FEE CTU in Prague, 23-Apr-2007
%

% parameter names and values variables format verification
if (size(sroc.params,1) ~= size(sroc.param_name,2))
  error('Number of rows in sroc.params must equal to number of parameters (given in sroc.param_name)')
  return
end

if (exist(sprintf('%s/sroc_%s.mat',...
		  sroc.ResPth,sroc.alg_abbrv), 'file'))
  ans = input('Results exist. Recompute? [N]/Y:', 's');
  if (isempty(ans))
    recompute = 0;
  else
    recompute = strcmp(lower(ans), 'y');
  end
  
  if (~recompute)
    load(sprintf('%s/sroc_%s', sroc.ResPth, sroc.alg_abbrv));
    return;
  else
    delete(sprintf('%s/sroc_%s.mat', sroc.ResPth, sroc.alg_abbrv))
    for sc = 1:size(sroc.scenes, 2)
      scene = sroc.scenes{sc};
      delete(sprintf('%s/%s/*', sroc.ResPth, scene))
    end
    
  end
  
else

  if (~exist(sprintf('%s',sroc.ResPth),'dir'))
    mkdir(sroc.ResPth)
  end
  for sc = 1:size(sroc.scenes, 2)
    scene = sroc.scenes{sc};
    if (~exist(sprintf('%s/%s',sroc.ResPth,scene),'dir'))
      mkdir(sprintf('%s/%s', sroc.ResPth, scene))
    end
  end

end

for sc = 1:size(sroc.scenes, 2)
  scene = sroc.scenes{sc};
  disp('%%%%%%%%%%%%%%%')
  disp(sprintf('Processing of scene: %s\n', scene))

  % load images, disparity search range
  l = double(imread(sprintf('%s/%s/left.png', sroc.ImgPth, scene)));
  r = double(imread(sprintf('%s/%s/right.png', sroc.ImgPth, scene)));
  % convert to gray-scale
  l = sum(l,3);
  r = sum(r,3);

  load(sprintf('%s/%s/drange', sroc.ImgPth, scene));
  dmin = floor(drange(1) - (drange(2)-drange(1))/2);
  dmax = ceil(drange(2) + (drange(2)-drange(1))/2);

  % load ground-truth, evaluation masks
  load(sprintf('%s/%s/gt', sroc.ImgPth, scene));
  load(sprintf('%s/%s/areas', sroc.ImgPth, scene));
  
  % error normalization
  err_norm = prod(size(GT)-[5,5]);

  err_rate = [];
  sparsity_rate = [];
  for i = 1:size(sroc.params, 2)
    str_param = '(';
    for j = 1:size(sroc.param_name,2)-1
      str_param = [str_param sroc.param_name{j} ', '];
    end
    str_param = [str_param sroc.param_name{end} ') = ('];
    for j = 1:size(sroc.param_name,2)-1
      str_param = sprintf('%s%.2f, ', str_param, sroc.params(j,i));
    end
    str_param = sprintf('%s%.2f)', str_param, sroc.params(end,i));
    disp(sprintf('parameters: %s\n', str_param))

    d = sroc_test_example(l, r, [dmin, dmax], ...
		  sroc.params(:,i));

    d1 = 1+floor(254*(d-drange(1))./(drange(2)-drange(1)));
    nn = isnan(d);
    d1 = uint8(min(max(d1,1),255));
    d1(nn) = 0;
    imwrite(d1,dmap(256), sprintf('%s/%s/dmap_%s-params%d.png',...
				  sroc.ResPth, scene, ...
				  sroc.alg_abbrv, i)); 

    save(sprintf('%s/%s/dmap_%s-params%d', sroc.ResPth, scene, ...
		 sroc.alg_abbrv, i),'d','dmin','dmax','drange');
    
    [errors1,norm1] = sroc_err(d, d_valid, GT, G,C,O, delta,'X');
    err_rate(i) = (errors1.MI + errors1.FP)/err_norm;
    sparsity_rate(i) = (errors1.FN)/norm1.FNR;

    disp(sprintf('\nCompleted: %.1f%c of scene ''%s''\n',...
		 100*(i/size(sroc.params,2)), '%', scene))
  end

  % compute ROC curve (find point indexes)
  sr = sparsity_rate;
  er = err_rate;
  Ind = [];
  while (~isempty(sr))
    ind = find(err_rate == min(er));  
    indx = find(er == min(er));
    ind1 = find(sparsity_rate(ind) == min(sr(indx)));
    Ind = [ind(ind1) Ind];
    
    ind2 = find((sr >= sparsity_rate(ind(ind1(1)))) & ...
		(er >= err_rate(ind(ind1(1)))));
    sr(ind2) = [];
    er(ind2) = [];
  end			    

  % compute efficiency E(A)
  Eff = sroc_efficiency([sparsity_rate(Ind); err_rate(Ind)]);


  sroc=setfield(sroc, sprintf('%s', scene),...
		struct('ER', err_rate, 'SR', sparsity_rate,...
		       'ROC', Ind, 'E', Eff));  
  
  disp(sprintf('Scene %d of %d completed\n', ...
	       sc, size(sroc.scenes,2)))
end

% compute data for expected performance (Mean)

mean_SR = [];
mean_ER = [];
for sc = 1:size(sroc.scenes, 2)
  scene = sroc.scenes{sc};      
  rates = getfield(sroc, sprintf('%s', scene));
  mean_SR = [mean_SR; rates.SR];
  mean_ER = [mean_ER; rates.ER];
end

sroc.expected.SR = sum(mean_SR, 1)./size(mean_SR,1);
sroc.expected.ER = sum(mean_ER, 1)./size(mean_ER,1);

% compute Mean ROC curve M (find point indexes) 
sr = sroc.expected.SR;
er = sroc.expected.ER;
Ind = [];
while (~isempty(sr))
  ind = find(sroc.expected.ER == min(er));  
  indx = find(er == min(er));
  ind1 = find(sroc.expected.SR(ind) == min(sr(indx)));
  Ind = [ind(ind1) Ind];
    
  ind2 = find((sr >= sroc.expected.SR(ind(ind1(1)))) & ...
	      (er >= sroc.expected.ER(ind(ind1(1)))));
  sr(ind2) = [];
  er(ind2) = [];
end			    
sroc.expected.ROC = Ind;

% compute efficiency E(A)
sroc.expected.E = sroc_efficiency([sroc.expected.SR(sroc.expected.ROC);...
				  sroc.expected.ER(sroc.expected.ROC)]);

% save results
save(sprintf('%s/sroc_%s',sroc.ResPth, sroc.alg_abbrv),'sroc');

% export E to 'efficiency.tex' file
if (sroc.export_results)
  sroc_export_eff(sroc);
end
