function sroc_export_eff(sroc)
%
%   sroc_export_eff(sroc)
%
%          exports computed efficiency of algorithm sroc to 
%          file 'Efficiency.tex'
%
% (c) Jana Kostliva (kostliva@cmp.felk.cvut.cz)
%     CMP, FEE CTU in Prague, 23-Apr-2007
%

fid = fopen(sprintf('%s/Efficiency.tex', sroc.ResPth),'w');

fprintf(fid,'\\documentclass{article} \n');
fprintf(fid,'\\usepackage[margin=20mm]{geometry} \n');
fprintf(fid,'\n');
fprintf(fid,'\\begin{document} \n');

fprintf(fid,'\n');
fprintf(fid,'\\begin{table}\n');
fprintf(fid,'\\centering \n');
st = repmat('c',1,size(sroc.scenes,2));
fprintf(fid,'\\begin{tabular}{%s} \n',['|l||',st,'|c|']);
fprintf(fid,'\\hline \n');
fprintf(fid,'~ & ');
for s=1:size(sroc.scenes,2),
    fprintf(fid,'%s &',sroc.scenes{s});
end
fprintf(fid,'expected\\\\ \n');
fprintf(fid,'\\hline \n');

fprintf(fid,'%s &',sroc.alg_abbrv);
for s = 1:size(sroc.scenes,2)
  rates = getfield(sroc, sprintf('%s', sroc.scenes{s}));  
  fprintf(fid,'%.3f &',rates.E);
end
fprintf(fid, '%.3f\\\\\\hline \n', sroc.expected.E);
fprintf(fid,'\\end{tabular} \n');
fprintf(fid,'\\caption{Efficiency $E(A)$.}\n');
fprintf(fid,'\\end{table}\n');

fprintf(fid,'\\end{document}\n');

fclose(fid);

