function sroc_export_impr(I, Dsr, Der, sroc)
%
%   sroc_export_impr(I, Dsr, Der, sroc)
%
%          exports computed improvement and dominant intervals 
%          of algorithm sroc to file 'Improvement.tex'
%
% (c) Jana Kostliva (kostliva@cmp.felk.cvut.cz)
%     CMP, FEE CTU in Prague, 23-Apr-2007
%

fid = fopen(sprintf('%s/Improvement.tex', sroc.ResPth),'w');

fprintf(fid,'\\documentclass{article} \n');
fprintf(fid,'\\usepackage[margin=20mm]{geometry} \n');
fprintf(fid,'\n');
fprintf(fid,'\\begin{document} \n');

fprintf(fid,'\n');
fprintf(fid,'\\begin{table}\n');
fprintf(fid,'\\centering \n');
str = repmat('c',1,size(sroc.scenes,2));
fprintf(fid,'\\begin{tabular}{%s} \n',['|l||',str,'|c|']);
fprintf(fid,'\\hline \n');
fprintf(fid,' & ');
for sc=1:size(sroc.scenes,2),
    fprintf(fid,'%s &',sroc.scenes{sc});
end
fprintf(fid,'expected\\\\ \n');
fprintf(fid,'\\hline \n');

fprintf(fid,'$I$ &');
for sc = 1:size(I,2)
  fprintf(fid,'%.3f',I(sc));
  if (sc<size(I,2))
    fprintf(fid,' & ');
  end
end
fprintf(fid, '\\\\\\hline \n');
fprintf(fid,'\\end{tabular} \n');
fprintf(fid,'\\caption{Improvement $I(%s|SFB)$.}\n',sroc.alg_abbrv);
fprintf(fid,'\\end{table}\n');

fprintf(fid,'\n');
fprintf(fid,'\\begin{table}\n');
fprintf(fid,'\\centering \n');
fprintf(fid,'\\tabcolsep1pt \n');
str = repmat('c',1,size(sroc.scenes,2));
fprintf(fid,'\\begin{tabular}{%s} \n',['|l||',str,'|c|']);
fprintf(fid,'\\hline \n');
fprintf(fid,'~ & ');
for sc=1:size(sroc.scenes,2),
    fprintf(fid,'%s &',sroc.scenes{sc});
end
fprintf(fid,'expected\\\\ \n');
fprintf(fid,'\\hline \n');

fprintf(fid,'$D_{SR}$ &',sroc.alg_abbrv);
for sc = 1:size(Dsr,2)
  if (size(Dsr{sc},1)>1)
    fprintf(fid, '$\\begin{array}{c}');
    for i=1:size(Dsr{sc},1)
      fprintf(fid,'~[%.3f, %.3f]', Dsr{sc}(i,1), Dsr{sc}(i,2));
      if (i<size(Dsr{sc},1))
        fprintf(fid,'\\\\');
      end
    end
    fprintf(fid,'\\end{array}$');
  else
    if (~isempty(Dsr{sc}))
      fprintf(fid,'[%.3f, %.3f]',Dsr{sc}(1,1), Dsr{sc}(1,2));
    else
      fprintf(fid,'--');
    end
  end
  if (sc<size(Dsr,2))
    fprintf(fid,' & ');
  end
end
fprintf(fid, '\\\\\\hline \n');
fprintf(fid,'\\end{tabular} \n');
fprintf(fid,'\\caption{SR-dominant intervals $D_{SR}(%s|SFB)$.}\n',...
	sroc.alg_abbrv);
fprintf(fid,'\\end{table}\n');

fprintf(fid,'\n');
fprintf(fid,'\\begin{table}\n');
fprintf(fid,'\\centering \n');
fprintf(fid,'\\tabcolsep1pt \n');
str = repmat('c',1,size(sroc.scenes,2));
fprintf(fid,'\\begin{tabular}{%s} \n',['|l||',str,'|c|']);
fprintf(fid,'\\hline \n');
fprintf(fid,'~ & ');
for sc=1:size(sroc.scenes,2),
    fprintf(fid,'%s &',sroc.scenes{sc});
end
fprintf(fid,'expected\\\\ \n');
fprintf(fid,'\\hline \n');

fprintf(fid,'$D_{ER}$ &');
for sc = 1:size(Der,2)
  if (size(Der{sc},1)>1)
    fprintf(fid, '$\\begin{array}{c}');
    for i=1:size(Der{sc},1)
      fprintf(fid,'~[%.3f, %.3f]', Der{sc}(i,1), Der{sc}(i,2));
      if (i<size(Der{sc},1))
        fprintf(fid,'\\\\');
      end
    end
    fprintf(fid,'\\end{array}$');
  else
    if (~isempty(Der{sc}))
      fprintf(fid,'[%.3f, %.3f]',Der{sc}(1,1), Der{sc}(1,2));
    else
      fprintf(fid,'--');
    end
  end
  if (sc<size(Der,2))
    fprintf(fid,' & ');
  end
end
fprintf(fid, '\\\\\\hline \n');
fprintf(fid,'\\end{tabular} \n');
fprintf(fid,'\\caption{ER-dominant intervals $D_{ER}(%s|SFB)$.}\n',...
	sroc.alg_abbrv);
fprintf(fid,'\\end{table}\n');



fprintf(fid,'\\end{document}\n');

fclose(fid);

