function sroc_export_impr_algs(I, Dsr, Der, sroc1, sroc2)
%
%   sroc_export_impr_algs(I, Dsr, Der, sroc1, sroc2)
%
%          exports computed improvement and dominant intervals 
%          between algorithms sroc1 and sroc2 to file 
%          'Improvement_alg1_alg2.tex'
%
% (c) Jana Kostliva (kostliva@cmp.felk.cvut.cz)
%     CMP, FEE CTU in Prague, 23-Apr-2007
%

scenes = {};
for sc = 1:size(sroc1.scenes,2)
  scene = sroc1.scenes{sc};
  
  if (~isfield(sroc1,sprintf('%s',scene)) | ~isfield(sroc2,sprintf('%s',scene)))
    continue;
  else
    scenes = {scenes{:}, scene};
  end
end

fid = fopen(sprintf('%s/Improvement_%s_%s.tex', sroc1.ResPth,...
		    sroc1.alg_abbrv, sroc2.alg_abbrv),'w');

fprintf(fid,'\\documentclass{article} \n');
fprintf(fid,'\\usepackage[margin=20mm]{geometry} \n');
fprintf(fid,'\n');
fprintf(fid,'\\begin{document} \n');

fprintf(fid,'\n');
fprintf(fid,'\\begin{table}\n');
fprintf(fid,'\\centering \n');
str = repmat('c',1,size(scenes,2));
fprintf(fid,'\\begin{tabular}{%s} \n',['|l||',str,'|c|']);
fprintf(fid,'\\hline \n');
fprintf(fid,' & ');
for sc=1:size(scenes,2),
    fprintf(fid,'%s &',scenes{sc});
end
fprintf(fid,'expected\\\\ \n');
fprintf(fid,'\\hline \n');

fprintf(fid,'$I(%s|%s)$ &',sroc1.alg_abbrv, sroc2.alg_abbrv);
for sc = 1:size(I,2)
  fprintf(fid,'%.3f',I(1,sc));
  if (sc<size(I,2))
    fprintf(fid,' & ');
  end
end
fprintf(fid, '\\\\\\hline \n');
fprintf(fid,'$I(%s|%s)$ &',sroc2.alg_abbrv, sroc1.alg_abbrv);
for sc = 1:size(I,2)
  fprintf(fid,'%.3f',I(2,sc));
  if (sc<size(I,2))
    fprintf(fid,' & ');
  end
end
fprintf(fid, '\\\\\\hline \n');
fprintf(fid,'\\end{tabular} \n');
fprintf(fid,'\\caption{Improvement of algorithms %s and %s.}\n',...
	sroc1.alg_abbrv, sroc2.alg_abbrv);
fprintf(fid,'\\end{table}\n');

fprintf(fid,'\n');
fprintf(fid,'\\begin{table}\n');
fprintf(fid,'\\centering \n');
fprintf(fid,'\\tabcolsep1pt \n');
str = repmat('c',1,size(scenes,2));
fprintf(fid,'\\begin{tabular}{%s} \n',['|l||',str,'|c|']);
fprintf(fid,'\\hline \n');
fprintf(fid,'~ & ');
for sc=1:size(scenes,2),
    fprintf(fid,'%s &',scenes{sc});
end
fprintf(fid,'expected\\\\ \n');
fprintf(fid,'\\hline \n');

fprintf(fid,'$D_{SR}(%s|%s)$ &',sroc1.alg_abbrv, sroc2.alg_abbrv);
for sc = 1:size(Dsr,2)
  if (size(Dsr{1,sc},1)>1)
    fprintf(fid, '$\\begin{array}{c}');
    for i=1:size(Dsr{1,sc},1)
      fprintf(fid,'~[%.3f, %.3f]', Dsr{1,sc}(i,1), Dsr{1,sc}(i,2));
      if (i<size(Dsr{1,sc},1))
        fprintf(fid,'\\\\');
      end
    end
    fprintf(fid,'\\end{array}$');
  else
    if (~isempty(Dsr{1,sc}))
      fprintf(fid,'[%.3f, %.3f]',Dsr{1,sc}(1,1), Dsr{1,sc}(1,2));
    else
      fprintf(fid,'--');
    end
  end
  if (sc<size(Dsr,2))
    fprintf(fid,' & ');
  end
end
fprintf(fid, '\\\\\\hline \n');
fprintf(fid,'$D_{SR}(%s|%s)$ &',sroc2.alg_abbrv, sroc2.alg_abbrv);
for sc = 1:size(Dsr,2)
  if (size(Dsr{2,sc},1)>1)
    fprintf(fid, '$\\begin{array}{c}');
    for i=1:size(Dsr{2,sc},1)
      fprintf(fid,'~[%.3f, %.3f]', Dsr{2,sc}(i,1), Dsr{2,sc}(i,2));
      if (i<size(Dsr{2,sc},1))
        fprintf(fid,'\\\\');
      end
    end
    fprintf(fid,'\\end{array}$');
  else
    if (~isempty(Dsr{2,sc}))
      fprintf(fid,'[%.3f, %.3f]',Dsr{2,sc}(1,1), Dsr{2,sc}(1,2));
    else
      fprintf(fid,'--');
    end
  end
  if (sc<size(Dsr,2))
    fprintf(fid,' & ');
  end
end
fprintf(fid, '\\\\\\hline \n');
fprintf(fid,'\\end{tabular} \n');
fprintf(fid,'\\caption{SR-dominant intervals of algorithms %s and %s.}\n',...
	sroc1.alg_abbrv, sroc2.alg_abbrv);
fprintf(fid,'\\end{table}\n');

fprintf(fid,'\n');
fprintf(fid,'\\begin{table}\n');
fprintf(fid,'\\centering \n');
fprintf(fid,'\\tabcolsep1pt \n');
str = repmat('c',1,size(scenes,2));
fprintf(fid,'\\begin{tabular}{%s} \n',['|l||',str,'|c|']);
fprintf(fid,'\\hline \n');
fprintf(fid,'~ & ');
for sc=1:size(scenes,2),
    fprintf(fid,'%s &',scenes{sc});
end
fprintf(fid,'expected\\\\ \n');
fprintf(fid,'\\hline \n');

fprintf(fid,'$D_{ER}(%s|%s)$ &', sroc1.alg_abbrv, sroc2.alg_abbrv);
for sc = 1:size(Der,2)
  if (size(Der{1,sc},1)>1)
    fprintf(fid, '$\\begin{array}{c}');
    for i=1:size(Der{1,sc},1)
      fprintf(fid,'~[%.3f, %.3f]', Der{1,sc}(i,1), Der{1,sc}(i,2));
      if (i<size(Der{1,sc},1))
        fprintf(fid,'\\\\');
      end
    end
    fprintf(fid,'\\end{array}$');
  else
    if (~isempty(Der{1,sc}))
      fprintf(fid,'[%.3f, %.3f]',Der{1,sc}(1,1), Der{1,sc}(1,2));
    else
      fprintf(fid,'--');
    end
  end
  if (sc<size(Der,2))
    fprintf(fid,' & ');
  end
end
fprintf(fid, '\\\\\\hline \n');
fprintf(fid,'$D_{ER}(%s|%s)$ &', sroc2.alg_abbrv, sroc1.alg_abbrv);
for sc = 1:size(Der,2)
  if (size(Der{2,sc},1)>1)
    fprintf(fid, '$\\begin{array}{c}');
    for i=1:size(Der{2,sc},1)
      fprintf(fid,'~[%.3f, %.3f]', Der{2,sc}(i,1), Der{2,sc}(i,2));
      if (i<size(Der{2,sc},1))
        fprintf(fid,'\\\\');
      end
    end
    fprintf(fid,'\\end{array}$');
  else
    if (~isempty(Der{2,sc}))
      fprintf(fid,'[%.3f, %.3f]',Der{2,sc}(1,1), Der{2,sc}(1,2));
    else
      fprintf(fid,'--');
    end
  end
  if (sc<size(Der,2))
    fprintf(fid,' & ');
  end
end
fprintf(fid, '\\\\\\hline \n');

fprintf(fid,'\\end{tabular} \n');
fprintf(fid,'\\caption{ER-dominant intervals of algorithms %s and %s.}\n',...
	sroc1.alg_abbrv, sroc2.alg_abbrv);
fprintf(fid,'\\end{table}\n');



fprintf(fid,'\\end{document}\n');

fclose(fid);

