function [I,Di,Di_] = sroc_impr_algs(rP1,rP2)
%
% [I,Di,Di_] = sroc_impr_algs(rP1,rP2)
%  
%     computes improvement of algorithm rP1 over algorithm rP2
%
%
%  rP1, rP2 ... ROC boundary points [SR;ER] (of size 2xm1, 2xm2)
%
%  Di ... Dominant inerval of rP1 over rP2
%         (kx2), where k is number of pieces of a dominant set
%  Di_... Dominant interval on vertical axis (error interval)
%
%  I ..improvement of rP1 over rP2
%
%
% (c) Jana Kostliva (kostliva@cmp.felk.cvut.cz)
%     CMP, FEE CTU in Prague, 23-Apr-2007
%


[Di,Di_] = sroc_dominant_intervals(rP1,rP2);

%Improvement
E1 = 0; E2 = 0;
for k=1:size(Di,1), %Di may not be contiguos
    a = Di(k,1); b = Di(k,2);
    A = Di_(k,1); B = Di_(k,2);
    
    r2 = rP2';
    ia = find(r2(:,2)==A);
    if ~isempty(ia),
        r2(ia,1) = a;
    end
    ib = find(r2(:,1)==b);
    if ~isempty(ib),
        r2(ib,2) = B;
    end
    

    E1 = E1 + sroc_efficiency(rP1,Di(k,:));
    E2 = E2 + sroc_efficiency(r2',Di(k,:));
end
I = E1-E2;

