function [I, Dsr, Der ] = sroc_improvements(sroc,sfb)
%
% [I, Dsr, Der] = sroc_improvements(sroc[,sfb])
%  
%     computes improvements and dominant intervals of algorithm sroc 
%     over sfb, if sroc.export_results is true, export results to a file
%     'improvement.tex'
%
%
%  Input:
%    sroc ... sroc profile of tested algorithm
%     sfb ... stereo feasibility boundary; 
%             optional, default: saved sfb.mat
%
%  Output:
%      I ... improvements for all (computed) scenes
%    Dsr ... SR-dominant intervals for all (computed) scenes
%    Der ... ER-dominant intervals for all (computed) scenes
%
%
% (c) Jana Kostliva (kostliva@cmp.felk.cvut.cz)
%     CMP, FEE CTU in Prague, 23-Apr-2007
%

if (nargin < 2)
  load(sprintf('%s/Results/sfb.mat',sroc.rootPth))
end

I = [];
Dsr = {};
Der = {};
for sc = 1:size(sroc.scenes,2)
  scene = sroc.scenes{sc};
  
  rates = getfield(sroc,sprintf('%s',scene));
  curr_sfb = getfield(sfb,sprintf('%s',scene));

  rP1 = [rates.SR(rates.ROC); rates.ER(rates.ROC)];
  rP2 = [curr_sfb.SR; curr_sfb.ER];
  [I(sc), Dsr{sc}, Der{sc}] = sroc_impr_algs(rP1, rP2);
end

rP1 = [sroc.expected.SR(sroc.expected.ROC);...
       sroc.expected.ER(sroc.expected.ROC)];
rP2 = [sfb.expected.SR; sfb.expected.ER];
[I(end+1), Dsr{end+1}, Der{end+1}] = sroc_impr_algs(rP1, rP2);


if (sroc.export_results)
  sroc_export_impr(I, Dsr, Der, sroc);
end

str = '';
str_num = '';
for i=1:size(sroc.scenes,2)
  str = sprintf('%s\t%s',str,sroc.scenes{i});
end
str = sprintf('%s\texpected',str);
for i=1:size(sroc.scenes,2)
  str_num = sprintf('%s\t%.3f',str_num,I(i));
end
str_num = sprintf('%s\t%.3f',str_num,I(end));

disp(sprintf('\nImprovement: I(%s|sfb_%s):\n%s\n%s',...
	     sroc.alg_abbrv,sfb.version,str,str_num))
