function [I, Dsr, Der ] = sroc_improvements_algs(sroc1,sroc2)
%
% [I, Dsr, Der] = sroc_improvements(sroc1, sroc2)
%  
%     computes improvements and dominant intervals between algorithms
%     sroc1 and sroc2; if sroc.export_results is true, export 
%     results to a file 'Improvement_alg1_alg2.tex'
%
%
%  Input:
%    sroc1, sroc2 ... profiles of the tested algorithms
%
%  Output:
%      I ... improvements for all (computed) scenes
%    Dsr ... SR-dominant intervals for all (computed) scenes
%    Der ... ER-dominant intervals for all (computed) scenes
%
%
% (c) Jana Kostliva (kostliva@cmp.felk.cvut.cz)
%     CMP, FEE CTU in Prague, 23-Apr-2007
%


I = [];
Dsr = {};
Der = {};
scenes = {};
for sc = 1:size(sroc1.scenes,2)
  scene = sroc1.scenes{sc};
  
  if ((~isfield(sroc1,sprintf('%s',scene))) | (~isfield(sroc2,sprintf('%s',scene))))
    continue;
  else
    scenes = {scenes{:}, scene};
    rates = getfield(sroc1,sprintf('%s',scene));
    rates1 = getfield(sroc2,sprintf('%s',scene));

    rP1 = [rates.SR(rates.ROC); rates.ER(rates.ROC)];
    rP2 = [rates1.SR(rates1.ROC); rates1.ER(rates1.ROC)];
    [I(1,sc), Dsr{1,sc}, Der{1,sc}] = sroc_impr_algs(rP1, rP2);
    [I(2,sc), Dsr{2,sc}, Der{2,sc}] = sroc_impr_algs(rP2, rP1);
  end
end

rP1 = [sroc1.expected.SR(sroc1.expected.ROC);...
       sroc1.expected.ER(sroc1.expected.ROC)];
rP2 = [sroc2.expected.SR(sroc2.expected.ROC);...
       sroc2.expected.ER(sroc2.expected.ROC)];
col = size(scenes,2) + 1;
[I(1,col), Dsr{1,col}, Der{1,col}] = sroc_impr_algs(rP1, rP2);
[I(2,col), Dsr{2,col}, Der{2,col}] = sroc_impr_algs(rP1, rP2);


if (sroc1.export_results | sroc2.export_results)
  sroc_export_impr_algs(I, Dsr, Der, sroc1, sroc2);
end

str = '';
str_num = '';
str_num1 = '';
for i=1:size(scenes,2)
  str = sprintf('%s\t%s',str,scenes{i});
end
str = sprintf('%s\texpected',str);
for i=1:size(scenes,2)
  str_num = sprintf('%s\t%.3f',str_num,I(1,i));
end
str_num = sprintf('%s\t%.3f',str_num,I(1,end));
for i=1:size(scenes,2)
  str_num1 = sprintf('%s\t%.3f',str_num1,I(2,i));
end
str_num = sprintf('%s\t%.3f',str_num,I(2,end));

disp(sprintf('\nImprovement:\n\t%s\nI(%s|%s):\t%s\nI(%s|%s):\t%s',...
	     str,sroc1.alg_abbrv,sroc2.alg_abbrv,str_num,...
	     sroc2.alg_abbrv,sroc1.alg_abbrv,str_num1))
