function sroc_prepare_upload(sroc)
%
%  sroc_prepare_upload(sroc)
%
%         prepares the results for upload as tgz-file
%
%  input:
%     sroc ... main evaluation variable with results of current 
%              algorithm
%
% (c) Jana Kostliva (kostliva@cmp.felk.cvut.cz)
%     CMP, FEE CTU in Prague, 23-Apr-2007
%

% tests if sroc profile has correct format
if (~correct_sroc(sroc))
   return
end

% tests if the algorithm is tested on all scenes
scenes = {'cones','slits','stripes','teddy','tsukuba', 'venus'};
if (~isempty(setdiff(scenes,sroc.scenes)))
  disp('Error: Algorithm is required to be tested on all scenes')
  return
end

% tests if fields identifying the algorithm are filled in
if (strcmp(sroc.alg_name,'noname') | isempty(sroc.alg_name))
  disp('Error: Algorithm name (field ''alg_name'') is required to be filled in')
  return
end  

if (strcmp(sroc.alg_authors,'noauthors') | isempty(sroc.alg_authors))
  disp('Error: Authors (field ''alg_authors'') is required to be filled in')
  return
end  

if (strcmp(sroc.alg_abbrv,'noabbrv') | isempty(sroc.alg_abbrv))
  disp('Error: Algorithm''s abbreviation (field ''alg_abbrv'') is required to be filled in')
  return
end  

if (strcmp(sroc.alg_bibref,'nobibref') | isempty(sroc.alg_bibref))
  disp('Error: Algorithm''s cit. reference (field ''alg_bibref'') is required to be filled in')
  return
end  

if (isunix)
eval(sprintf('!tar -C %s/Results -zcf %s.tgz %s --exclude=''Eff*'' --exclude=''Impr*''',...
	     sroc.rootPth,sroc.alg_abbrv, sroc.alg_abbrv))
else
  disp('The results are correct and ready for upload.')
  disp(sprintf(' Please prepare the zip-file manually by zipping the directory ''%s''', sroc.alg_abbrv))
end
