function tofiles(params)
%
% tofiles 
%   saves all named figures to Encapsulated PostScript files 
% 
% tofiles eps
%   saves to eps color format
%
% tofiles pdf
%   saves to pdf format
%
% tofiles fig
%   saves to matfig format, use hgload to load the file
%
% See also: PRINT, SET

% October 14, 1994: Radim Sara, CVL Prague
% Modified Jan 30, 1998, Radim Sara (sara@cmp.felk.cvut.cz)
% Modified for fig: Feb 11, 2006, Radim Sara (sara@cmp.felk.cvut.cz)
 
 if ~exist('params')
  params = [];
 end

 if isempty(params)
  params = '-eps'; 
 end
 
 switch lower(params)
  
  case {'-dpdf', '-pdf', 'pdf'}
   dopdf = 1;
   params = '-depsc2';
   sn = savetofile(params,dopdf);
   
  case {'eps','-eps'}
   dopdf = 0;
   params = '-depsc2';
   sn = savetofile(params,dopdf);
   
  case {'fig', '-fig'}
   sn = savetofig;
   
  otherwise
   error(sprintf('Unknown parameter %s',params))
 end
 
return

function savedNo = savetofig
 
 figures = sort(get(0,'Children'))'; % list of all figures
 savedNo = 0;
 for f = 1:length(figures),
  name = get(figures(f), 'Name');
  if length(name) > 0
   saveas(f,[name,'.matfig'],'fig')
   disp([name '.matfig']);
   savedNo = savedNo+1;
  end
 end
 
return
 
function savedNo = savetofile(params,dopdf)

 figures = sort(get(0,'Children'))'; % list of all figures
 savedNo = 0;
 for f = 1:length(figures),
  name = get(figures(f), 'Name');
  if length(name) > 8
   %disp(['Warning: name "' name '" too long.']);
  end
  if length(name) > 0
   eval(['print ' params ' -f' num2str(figures(f)) ' ' name]);
   if dopdf
    
    [s,w]=unix(sprintf('epstopdf %s.eps',name));
    if s ~= 0
     error(sprintf('Could not run epstopdf on file %s',name))
    end
    delete(sprintf('%s.eps',name))
    disp([name '.pdf']);
   else
    disp([name '.eps']);
   end
   savedNo = savedNo+1;
  end
 end

return
